@@ -954,26 +954,26 @@ fi
 if ___eapi_has_einstalldocs; then
 	einstalldocs() {
 		(
-			docinto .
 			if ! declare -p DOCS &>/dev/null ; then
 				local d
 				for d in README* ChangeLog AUTHORS NEWS TODO CHANGES \
 						THANKS BUGS FAQ CREDITS CHANGELOG ; do
-					[[ -s ${d} ]] && dodoc "${d}"
+					[[ -s ${d} ]] && docinto / && dodoc "${d}"
 				done
 			elif [[ $(declare -p DOCS) == "declare -a"* ]] ; then
-				[[ ${DOCS[@]} ]] && dodoc -r "${DOCS[@]}"
+				[[ ${DOCS[@]} ]] && docinto / && dodoc -r "${DOCS[@]}"
 			else
-				[[ ${DOCS} ]] && dodoc -r ${DOCS}
+				[[ ${DOCS} ]] && docinto / && dodoc -r ${DOCS}
 			fi
 		)
 
 		(
-			docinto html
 			if [[ $(declare -p HTML_DOCS 2>/dev/null) == "declare -a"* ]] ; then
-				[[ ${HTML_DOCS[@]} ]] && dodoc -r "${HTML_DOCS[@]}"
+				[[ ${HTML_DOCS[@]} ]] && \
+					docinto html && dodoc -r "${HTML_DOCS[@]}"
 			else
-				[[ ${HTML_DOCS} ]] && dodoc -r ${HTML_DOCS}
+				[[ ${HTML_DOCS} ]] && \
+					docinto html && dodoc -r ${HTML_DOCS}
 			fi
 		)
 	}
@@ -1079,6 +1079,9 @@ fi
 
 if ___eapi_has_eapply_user; then
 	eapply_user() {
+		[[ ${EBUILD_PHASE} == prepare ]] || \
+			die "eapply_user() called during invalid phase: ${EBUILD_PHASE}"
+		# keep path in __dyn_prepare in sync!
 		local tagfile=${T}/.portage_user_patches_applied
 		[[ -f ${tagfile} ]] && return
 		>> "${tagfile}"
