@@ -16,7 +16,7 @@ module_spec = {
 			'functions': ['check', 'fix', 'purge'],
 			'func_desc': {
 				'purge': {
-					'short': '-P', 'long': '--purge-tracker',
+					'short': '-P', 'long': '--purge',
 					'help': 'Removes the list of previously failed merges.' +
 							' WARNING: Only use this option if you plan on' +
 							' manually fixing them or do not want them'
