@@ -1,4 +1,4 @@
-# Copyright 2010-2014 Gentoo Foundation
+# Copyright 2010-2015 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 from __future__ import unicode_literals
@@ -15,6 +15,7 @@ import platform
 import pwd
 import re
 import sys
+import traceback
 import warnings
 
 from _emerge.Package import Package
@@ -159,8 +160,8 @@ class config(object):
 		'repository', 'RESTRICT', 'LICENSE',)
 
 	_module_aliases = {
-		"cache.metadata_overlay.database" : "portage.cache.flat_hash.database",
-		"portage.cache.metadata_overlay.database" : "portage.cache.flat_hash.database",
+		"cache.metadata_overlay.database" : "portage.cache.flat_hash.mtime_md5_database",
+		"portage.cache.metadata_overlay.database" : "portage.cache.flat_hash.mtime_md5_database",
 	}
 
 	_case_insensitive_vars = special_env_vars.case_insensitive_vars
@@ -443,7 +444,7 @@ class config(object):
 				(user_auxdbmodule, modules_file))
 
 			self.modules["default"] = {
-				"portdbapi.auxdbmodule":  "portage.cache.flat_hash.database",
+				"portdbapi.auxdbmodule":  "portage.cache.flat_hash.mtime_md5_database",
 			}
 
 			self.configlist=[]
@@ -537,13 +538,13 @@ class config(object):
 			#filling PORTDIR and PORTDIR_OVERLAY variable for compatibility
 			main_repo = self.repositories.mainRepo()
 			if main_repo is not None:
-				self["PORTDIR"] = main_repo.user_location
+				self["PORTDIR"] = main_repo.location
 				self.backup_changes("PORTDIR")
 				expand_map["PORTDIR"] = self["PORTDIR"]
 
 			# repoman controls PORTDIR_OVERLAY via the environment, so no
 			# special cases are needed here.
-			portdir_overlay = list(self.repositories.repoUserLocationList())
+			portdir_overlay = list(self.repositories.repoLocationList())
 			if portdir_overlay and portdir_overlay[0] == self["PORTDIR"]:
 				portdir_overlay = portdir_overlay[1:]
 
@@ -836,7 +837,8 @@ class config(object):
 			# reasonable defaults; this is important as without USE_ORDER,
 			# USE will always be "" (nothing set)!
 			if "USE_ORDER" not in self:
-				self.backupenv["USE_ORDER"] = "env:pkg:conf:defaults:pkginternal:repo:env.d"
+				self["USE_ORDER"] = "env:pkg:conf:defaults:pkginternal:repo:env.d"
+				self.backup_changes("USE_ORDER")
 
 			if "CBUILD" not in self and "CHOST" in self:
 				self["CBUILD"] = self["CHOST"]
@@ -1257,13 +1259,13 @@ class config(object):
 				use = frozenset(settings['PORTAGE_USE'].split())
 
 			values['ACCEPT_LICENSE'] = settings._license_manager.get_prunned_accept_license( \
-				settings.mycpv, use, settings['LICENSE'], settings['SLOT'], settings.get('PORTAGE_REPO_NAME'))
+				settings.mycpv, use, settings.get('LICENSE', ''), settings.get('SLOT'), settings.get('PORTAGE_REPO_NAME'))
 			values['PORTAGE_RESTRICT'] = self._restrict(use, settings)
 			return values
 
 		def _restrict(self, use, settings):
 			try:
-				restrict = set(use_reduce(settings['RESTRICT'], uselist=use, flat=True))
+				restrict = set(use_reduce(settings.get('RESTRICT', ''), uselist=use, flat=True))
 			except InvalidDependString:
 				restrict = set()
 			return ' '.join(sorted(restrict))
@@ -2567,7 +2569,23 @@ class config(object):
 		try:
 			return self._getitem(key)
 		except KeyError:
-			return '' # for backward compat, don't raise KeyError
+			if portage._internal_caller:
+				stack = traceback.format_stack()[:-1] + traceback.format_exception(*sys.exc_info())[1:]
+				try:
+					# Ensure that output is written to terminal.
+					with open("/dev/tty", "w") as f:
+						f.write("=" * 96 + "\n")
+						f.write("=" * 8 + " Traceback for invalid call to portage.package.ebuild.config.config.__getitem__ " + "=" * 8 + "\n")
+						f.writelines(stack)
+						f.write("=" * 96 + "\n")
+				except Exception:
+					pass
+				raise
+			else:
+				warnings.warn(_("Passing nonexistent key %r to %s is deprecated. Use %s instead.") %
+					(key, "portage.package.ebuild.config.config.__getitem__",
+					"portage.package.ebuild.config.config.get"), DeprecationWarning, stacklevel=2)
+				return ""
 
 	def _getitem(self, mykey):
 
@@ -2694,10 +2712,9 @@ class config(object):
 				filter_calling_env = True
 
 		environ_whitelist = self._environ_whitelist
-		for x in self:
+		for x, myvalue in self.iteritems():
 			if x in environ_filter:
 				continue
-			myvalue = self[x]
 			if not isinstance(myvalue, basestring):
 				writemsg(_("!!! Non-string value in config: %s=%s\n") % \
 					(x, myvalue), noiselevel=-1)
