@@ -1,4 +1,4 @@
-# Copyright 2010 Gentoo Foundation
+# Copyright 2010-2013 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 """Provides an easy-to-use python interface to Gentoo's metadata.xml file.
@@ -28,18 +28,49 @@
 		'Thomas Mills Hinkle'
 """
 
+from __future__ import unicode_literals
+
 __all__ = ('MetaDataXML',)
 
-try:
-	import xml.etree.cElementTree as etree
-except ImportError:
+import sys
+
+if sys.hexversion < 0x2070000 or \
+	(sys.hexversion < 0x3020000 and sys.hexversion >= 0x3000000):
+	# Our _MetadataTreeBuilder usage is incompatible with
+	# cElementTree in Python 2.6, 3.0, and 3.1:
+	#  File "/usr/lib/python2.6/xml/etree/ElementTree.py", line 644, in findall
+	#    assert self._root is not None
 	import xml.etree.ElementTree as etree
+else:
+	try:
+		import xml.etree.cElementTree as etree
+	except (SystemExit, KeyboardInterrupt):
+		raise
+	except (ImportError, SystemError, RuntimeError, Exception):
+		# broken or missing xml support
+		# http://bugs.python.org/issue14988
+		import xml.etree.ElementTree as etree
+
+try:
+	from xml.parsers.expat import ExpatError
+except (SystemExit, KeyboardInterrupt):
+	raise
+except (ImportError, SystemError, RuntimeError, Exception):
+	ExpatError = SyntaxError
 
 import re
-import portage
-from portage import os
+import xml.etree.ElementTree
+from portage import _encodings, _unicode_encode
 from portage.util import unique_everseen
 
+class _MetadataTreeBuilder(xml.etree.ElementTree.TreeBuilder):
+	"""
+	Implements doctype() as required to avoid deprecation warnings with
+	Python >=2.7.
+	"""
+	def doctype(self, name, pubid, system):
+		pass
+
 class _Maintainer(object):
 	"""An object for representing one maintainer.
 
@@ -49,6 +80,8 @@ class _Maintainer(object):
 	@ivar name: Maintainer's name. Used for both Gentoo and upstream.
 	@type description: str or None
 	@ivar description: Description of what a maintainer does. Gentoo only.
+	@type maint_type: str or None
+	@ivar maint_type: GLEP67 maintainer type (project or person). Gentoo only.
 	@type restrict: str or None
 	@ivar restrict: e.g. &gt;=portage-2.2 means only maintains versions
 		of Portage greater than 2.2. Should be DEPEND string with < and >
@@ -61,10 +94,10 @@ class _Maintainer(object):
 		self.email = None
 		self.name = None
 		self.description = None
+		self.maint_type = node.get('type')
 		self.restrict = node.get('restrict')
 		self.status = node.get('status')
-		maint_attrs = node.getchildren()
-		for attr in maint_attrs:
+		for attr in node:
 			setattr(self, attr.tag, attr.text)
 
 	def __repr__(self):
@@ -79,7 +112,7 @@ class _Useflag(object):
 	@type name: str or None
 	@ivar name: USE flag
 	@type restrict: str or None
-	@ivar restrict: e.g. &gt;=portage-2.2 means flag is only avaiable in
+	@ivar restrict: e.g. &gt;=portage-2.2 means flag is only available in
 		versions greater than 2.2
 	@type description: str
 	@ivar description: description of the USE flag
@@ -174,9 +207,13 @@ class MetaDataXML(object):
 		self._xml_tree = None
 
 		try:
-			self._xml_tree = etree.parse(metadata_xml_path)
+			self._xml_tree = etree.parse(_unicode_encode(metadata_xml_path,
+				encoding=_encodings['fs'], errors='strict'),
+				parser=etree.XMLParser(target=_MetadataTreeBuilder()))
 		except ImportError:
 			pass
+		except ExpatError as e:
+			raise SyntaxError("%s" % (e,))
 
 		if isinstance(herds, etree.ElementTree):
 			herds_etree = herds
@@ -209,7 +246,9 @@ class MetaDataXML(object):
 
 		if self._herdstree is None:
 			try:
-				self._herdstree = etree.parse(self._herds_path)
+				self._herdstree = etree.parse(_unicode_encode(self._herds_path,
+					encoding=_encodings['fs'], errors='strict'),
+					parser=etree.XMLParser(target=_MetadataTreeBuilder()))
 			except (ImportError, IOError, SyntaxError):
 				return None
 
@@ -217,7 +256,13 @@ class MetaDataXML(object):
 		if herd in ('no-herd', 'maintainer-wanted', 'maintainer-needed'):
 			return None
 
-		for node in self._herdstree.getiterator('herd'):
+		try:
+			# Python 2.7 or >=3.2
+			iterate = self._herdstree.iter
+		except AttributeError:
+			iterate = self._herdstree.getiterator
+
+		for node in iterate('herd'):
 			if node.findtext('name') == herd:
 				return node.findtext('email')
 
@@ -292,8 +337,13 @@ class MetaDataXML(object):
 			if self._xml_tree is None:
 				self._useflags = tuple()
 			else:
+				try:
+					# Python 2.7 or >=3.2
+					iterate = self._xml_tree.iter
+				except AttributeError:
+					iterate = self._xml_tree.getiterator
 				self._useflags = tuple(_Useflag(node) \
-					for node in self._xml_tree.getiterator('flag'))
+					for node in iterate('flag'))
 
 		return self._useflags
 
